Enum rustc_ap_rustc_session::config::ExternDepSpec [−][src]
Supplied source location of a dependency - for example in a build specification file like Cargo.toml. We support several syntaxes: if it makes sense to reference a file and line, then the build system can specify that. On the other hand, it may make more sense to have an arbitrary raw string.
Variants
Raw(String)Raw string
Json(Json)Raw data in json format