Enum rustc_ap_rustc_session::config::ExternLocation [−][src]
pub enum ExternLocation {
FoundInLibrarySearchDirectories,
ExactPaths(BTreeSet<CanonicalizedPath>),
}Variants
Indicates to look for the library in the search paths.
Added via --extern name.
ExactPaths(BTreeSet<CanonicalizedPath>)The locations where this extern entry must be found.
The CrateLoader is responsible for loading these and figuring out
which one to use.
Added via --extern prelude_name=some_file.rlib