Enum rustc_ap_rustc_session::config::InstrumentCoverage [−][src]
pub enum InstrumentCoverage {
All,
ExceptUnusedGenerics,
ExceptUnusedFunctions,
Off,
}Expand description
The different settings that the -Z instrument-coverage flag can have.
Coverage instrumentation now supports combining -Z instrument-coverage
with compiler and linker optimization (enabled with -O or -C opt-level=1
and higher). Nevertheless, there are many variables, depending on options
selected, code structure, and enabled attributes. If errors are encountered,
either while compiling or when generating llvm-cov show reports, consider
lowering the optimization level, including or excluding -C link-dead-code,
or using -Z instrument-coverage=except-unused-functions or -Z instrument-coverage=except-unused-generics.
Note that ExceptUnusedFunctions means: When mapgen.rs generates the
coverage map, it will not attempt to generate synthetic functions for unused
(and not code-generated) functions (whether they are generic or not). As a
result, non-codegenned functions will not be included in the coverage map,
and will not appear, as covered or uncovered, in coverage reports.
ExceptUnusedGenerics will add synthetic functions to the coverage map,
unless the function has type parameters.
Variants
Default -Z instrument-coverage or -Z instrument-coverage=statement
-Z instrument-coverage=except-unused-generics
-Z instrument-coverage=except-unused-functions
-Z instrument-coverage=off (or no, etc.)