Enum rustc_ap_rustc_session::config::TrimmedDefPaths [−][src]
pub enum TrimmedDefPaths {
Never,
Always,
GoodPath,
}Expand description
Parameter to control path trimming.
Variants
try_print_trimmed_def_path never prints a trimmed path and never calls the expensive query
try_print_trimmed_def_path calls the expensive query, the query doesn’t call delay_good_path_bug
try_print_trimmed_def_path calls the expensive query, the query calls delay_good_path_bug