Struct rustc_ap_rustc_session::config::ExternEntry [−][src]
pub struct ExternEntry {
pub location: ExternLocation,
pub is_private_dep: bool,
pub add_prelude: bool,
}Fields
location: ExternLocationis_private_dep: boolIndicates this is a “private” dependency for the
exported_private_dependencies lint.
This can be set with the priv option like
--extern priv:name=foo.rlib.
add_prelude: boolAdd the extern entry to the extern prelude.
This can be disabled with the noprelude option like
--extern noprelude:name.
Implementations