Struct rustc_ap_rustc_session::config::OutputFilenames [−][src]
pub struct OutputFilenames {
pub out_directory: PathBuf,
pub single_output_file: Option<PathBuf>,
pub outputs: OutputTypes,
// some fields omitted
}Fields
out_directory: PathBufsingle_output_file: Option<PathBuf>outputs: OutputTypesImplementations
pub fn new(
out_directory: PathBuf,
out_filestem: String,
single_output_file: Option<PathBuf>,
extra: String,
outputs: OutputTypes
) -> SelfGets the path where a compilation artifact of the given type for the given codegen unit should be placed on disk. If codegen_unit_name is None, a path distinct from those of any codegen unit will be generated.
Like temp_path, but specifically for dwarf objects.
Like temp_path, but also supports things where there is no corresponding
OutputType, like noopt-bitcode or lto-bitcode.
pub fn split_dwarf_path(
&self,
split_debuginfo_kind: SplitDebuginfo,
cgu_name: Option<&str>
) -> Option<PathBuf>
pub fn split_dwarf_path(
&self,
split_debuginfo_kind: SplitDebuginfo,
cgu_name: Option<&str>
) -> Option<PathBuf>Returns the path for the Split DWARF file - this can differ depending on which Split DWARF mode is being used, which is the logic that this function is intended to encapsulate.