Enum rustc_ap_rustc_session::CtfeBacktrace [−][src]
pub enum CtfeBacktrace {
Disabled,
Capture,
Immediate,
}Expand description
The behavior of the CTFE engine when an error occurs with regards to backtraces.
Variants
Do nothing special, return the error as usual without a backtrace.
Capture a backtrace at the point the error is created and return it in the error (to be printed later if/when the error ever actually gets shown to the user).
Capture a backtrace at the point the error is created and immediately print it out.