Struct rustc_ap_rustc_session::parse::GatedSpans [−][src]
Collected spans during parsing for places where a certain feature was
used and should be feature gated accordingly in check_crate.
Fields
spans: Lock<FxHashMap<Symbol, Vec<Span>>>Implementations
Feature gate the given span under the given feature
which is same Symbol used in active.rs.
Ungate the last span under the given feature.
Panics if the given span wasn’t the last one.
Using this is discouraged unless you have a really good reason to.
Is the provided feature gate ungated currently?
Using this is discouraged unless you have a really good reason to.