Enum rustc_ap_rustc_session::utils::NativeLibKind [−][src]
pub enum NativeLibKind {
Static {
bundle: Option<bool>,
whole_archive: Option<bool>,
},
Dylib {
as_needed: Option<bool>,
},
RawDylib,
Framework {
as_needed: Option<bool>,
},
Unspecified,
}Variants
Static library (e.g. libfoo.a on Linux or foo.lib on Windows/MSVC)
Show fields
Dynamic library (e.g. libfoo.so on Linux)
or an import library corresponding to a dynamic library (e.g. foo.lib on Windows/MSVC).
Show fields
Dynamic library (e.g. foo.dll on Windows) without a corresponding import library.
A macOS-specific kind of dynamic libraries.
Show fields
The library kind wasn’t specified, Dylib is currently used as a default.